==> 0.0.24.tar.gz: lib/component/file_upload_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/pages/file_preview_page.dart';
import 'package:vone_ipfs/pages/image_picker_dialog.dart';
import 'package:vone_ipfs/pages/online_file_page.dart';
import 'package:vone_ipfs/utils/ifps_dialog_utils.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';

class FileUploadView extends StatefulWidget {
  List<UploadResultEntity> selectedFile;
  Function(List<UploadResultEntity> files) filesCallback;
  Widget? header;
  bool isAllowCloud;
  String dirId;
  String dirName;
  bool isFixedDir;
  bool isCanEdit;
  IPFSFileType fileType;
  List<String>? allowedExtensions;
  int maxCount;

  FileUploadView(
      this.selectedFile, this.dirId, this.dirName, this.filesCallback,
      {Key? key,
      this.header,
      this.isAllowCloud = true,
      this.isFixedDir = false,
      this.isCanEdit = true,
      this.fileType = IPFSFileType.any,
      this.allowedExtensions,
      this.maxCount = -1})
      : super(key: key);

  @override
  _FileUploadViewState createState() => _FileUploadViewState();
}

class _FileUploadViewState extends State<FileUploadView> {
  List<UploadResultEntity> files = [];
  int maxCount = -1;

  @override
  void initState() {
    super.initState();
    setState(() {
      maxCount = widget.maxCount;
    });
  }

  @override
  Widget build(BuildContext context) {
    if (widget.selectedFile.isNotEmpty) {
      files = widget.selectedFile;
      widget.selectedFile = [];
    }
    return Container(
      child: ListView(
        shrinkWrap: true,
        children: _buildFileList(),
      ),
    );
  }

  _buildFileList() {
    List<Widget> filesWidget = [];
    filesWidget.add(InkWell(
      child: widget.header ?? _buildHeader(),
      onTap: () {
        if (maxCount > 0 && files.length >= maxCount) {
          ToastUtils.show('已超过最大上传文件数');
          return;
        }
        if (widget.isAllowCloud) {
          _showDialog();
        } else {
          _localUpload();
        }
      },
    ));
    for (int i = 0; i < files.length; i++) {
      filesWidget.add(InkWell(
        child: _buildFilesItem(i),
        onTap: () {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(fileUrl: '${files[i].filePath}');
          }));
        },
      ));
    }
    return filesWidget;
  }

  _buildHeader() {
    return widget.isCanEdit
        ? IntrinsicHeight(
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: const [
                Text(
                  '上传附件',
                  style: TextStyle(fontSize: 14, color: Colors.black),
                ),
                Text('上传', style: TextStyle(fontSize: 14, color: Colors.blue))
              ],
            ),
          )
        : const Text("");
  }

  _buildFilesItem(int index) {
    return Padding(
      padding: EdgeInsets.symmetric(vertical: 8),
      child: Row(
        children: [
          IPFSUtils.getFileIconBySuffix(files[index].fileName),
          SizedBox(
            width: 10,
          ),
          Expanded(
            child: Text(
              '${files[index].fileName}',
              overflow: TextOverflow.ellipsis,
              style: TextStyle(fontSize: 14, color: Colors.black87),
            ),
          ),
          Visibility(
            child: InkWell(
              child: const Icon(
                Icons.close,
                size: 20,
              ),
              onTap: () {
                files.removeAt(index);
                if (widget.filesCallback != null) {
                  widget.filesCallback(files);
                }
                setState(() {});
              },
            ),
            visible: widget.isCanEdit,
          )
        ],
      ),
    );
  }

  _showDialog() {
    showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context, //state.context,
        builder: (BuildContext context) {
          return ImagePickerDialog(
            localCallback: () {
              _localUpload();
            },
            cloudCallback: () {
              Navigator.push(context, MaterialPageRoute(builder: (context) {
                return OnlineFilePage(
                  widget.dirId,
                  widget.dirName,
                  (result) {
                    if (result.isNotEmpty) {
                      for (var element in result) {
                        String filePath = IPFSUtils.instance!
                            .getFilePath(element.id, element.fileName);
                        String coverPath = '';
                        if(element.fileType=='video'){
                            String coverParam = 'fileID=${element.id}&secretKey=${IPFSUtils.instance!.secretKey}';
                            coverPath = IPFSUtils.instance!.getCoverPath(coverParam);
                        }
                        print('coverPath===>$coverPath');
                        files.add(UploadResultEntity(
                            filePath, coverPath, element.fileName));
                      }
                      if (widget.filesCallback != null) {
                        widget.filesCallback(files);
                      }
                      setState(() {});
                    }
                  },
                  fileType: widget.fileType,
                  allowedExtensions: widget.allowedExtensions,
                  maxCount: maxCount > 0 ? maxCount - files.length : 9,
                );
              }));
            },
          );
        });
  }

  void _localUpload() {
    if (widget.isFixedDir) {
      _fileUpload();
    } else {
      IPFSDialog.showFileUpload(
          context, widget.dirId, widget.dirName, widget.fileType, (value) {
        setState(() {
          files.addAll(value);
        });
      }, widget.allowedExtensions);
    }
  }

  _fileUpload() {
    IPFSUtils.instance!.fileUpload(context, (value) {
      files.add(value);
      if (widget.filesCallback != null) {
        widget.filesCallback(files);
      }
      setState(() {});
    }, widget.dirId, widget.fileType,
        allowedExtensions: widget.allowedExtensions);
  }
}

==> 0.0.29.tar.gz: lib/component/file_upload_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/pages/file_preview_page.dart';
import 'package:vone_ipfs/pages/image_picker_dialog.dart';
import 'package:vone_ipfs/pages/online_file_page.dart';
import 'package:vone_ipfs/utils/ifps_dialog_utils.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';

class FileUploadView extends StatefulWidget {
  List<UploadResultEntity> selectedFile;
  Function(List<UploadResultEntity> files) filesCallback;
  Widget? header;
  bool isAllowCloud;
  String dirId;
  String dirName;
  bool isFixedDir;
  bool isCanEdit;
  IPFSFileType fileType;
  List<String>? allowedExtensions;
  int maxCount;

  FileUploadView(
      this.selectedFile, this.dirId, this.dirName, this.filesCallback,
      {Key? key,
      this.header,
      this.isAllowCloud = true,
      this.isFixedDir = false,
      this.isCanEdit = true,
      this.fileType = IPFSFileType.any,
      this.allowedExtensions,
      this.maxCount = -1})
      : super(key: key);

  @override
  _FileUploadViewState createState() => _FileUploadViewState();
}

class _FileUploadViewState extends State<FileUploadView> {
  List<UploadResultEntity> files = [];
  int maxCount = -1;

  @override
  void initState() {
    super.initState();
    setState(() {
      maxCount = widget.maxCount;
    });
  }

  @override
  Widget build(BuildContext context) {
    if (widget.selectedFile.isNotEmpty) {
      files = widget.selectedFile;
      widget.selectedFile = [];
    }
    return Container(
      child: ListView(
        shrinkWrap: true,
        children: _buildFileList(),
      ),
    );
  }

  _buildFileList() {
    List<Widget> filesWidget = [];
    filesWidget.add(InkWell(
      child: widget.header ?? _buildHeader(),
      onTap: () {
        if (maxCount > 0 && files.length >= maxCount) {
          ToastUtils.show('已超过最大上传文件数');
          return;
        }
        if (widget.isAllowCloud) {
          _showDialog();
        } else {
          _localUpload();
        }
      },
    ));
    for (int i = 0; i < files.length; i++) {
      filesWidget.add(InkWell(
        child: _buildFilesItem(i),
        onTap: () {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(fileUrl: '${files[i].url}');
          }));
        },
      ));
    }
    return filesWidget;
  }

  _buildHeader() {
    return widget.isCanEdit
        ? IntrinsicHeight(
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: const [
                Text(
                  '上传附件',
                  style: TextStyle(fontSize: 14, color: Colors.black),
                ),
                Text('上传', style: TextStyle(fontSize: 14, color: Colors.blue))
              ],
            ),
          )
        : const Text("");
  }

  _buildFilesItem(int index) {
    return Padding(
      padding: EdgeInsets.symmetric(vertical: 8),
      child: Row(
        children: [
          IPFSUtils.getFileIconBySuffix(files[index].name),
          SizedBox(
            width: 10,
          ),
          Expanded(
            child: Text(
              '${files[index].name}',
              overflow: TextOverflow.ellipsis,
              style: TextStyle(fontSize: 14, color: Colors.black87),
            ),
          ),
          Visibility(
            child: InkWell(
              child: const Icon(
                Icons.close,
                size: 20,
              ),
              onTap: () {
                files.removeAt(index);
                if (widget.filesCallback != null) {
                  widget.filesCallback(files);
                }
                setState(() {});
              },
            ),
            visible: widget.isCanEdit,
          )
        ],
      ),
    );
  }

  _showDialog() {
    showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context, //state.context,
        builder: (BuildContext context) {
          return ImagePickerDialog(
            localCallback: () {
              _localUpload();
            },
            cloudCallback: () {
              Navigator.push(context, MaterialPageRoute(builder: (context) {
                return OnlineFilePage(
                  widget.dirId,
                  widget.dirName,
                  (result) {
                    if (result.isNotEmpty) {
                      for (var element in result) {
                        String filePath = IPFSUtils.instance!
                            .getFilePath(element.id, element.name);
                        String coverPath = '';
                        if(element.fileType=='video'){
                            String coverParam = 'fileID=${element.id}&secretKey=${IPFSUtils.instance!.secretKey}';
                            coverPath = IPFSUtils.instance!.getCoverPath(coverParam);
                        }
                        print('coverPath===>$coverPath');
                        files.add(UploadResultEntity(
                            filePath, coverPath, element.name,element.size));
                      }
                      if (widget.filesCallback != null) {
                        widget.filesCallback(files);
                      }
                      setState(() {});
                    }
                  },
                  fileType: widget.fileType,
                  allowedExtensions: widget.allowedExtensions,
                  maxCount: maxCount > 0 ? maxCount - files.length : 9,
                );
              }));
            },
          );
        });
  }

  void _localUpload() {
    if (widget.isFixedDir) {
      _fileUpload();
    } else {
      IPFSDialog.showFileUpload(
          context, widget.dirId, widget.dirName, widget.fileType, (value) {
        setState(() {
          files.addAll(value);
        });
      }, widget.allowedExtensions);
    }
  }

  _fileUpload() {
    IPFSUtils.instance!.fileUpload(context, (value) {
      files.add(value);
      if (widget.filesCallback != null) {
        widget.filesCallback(files);
      }
      setState(() {});
    }, widget.dirId, widget.fileType,
        allowedExtensions: widget.allowedExtensions);
  }
}
